# Copyright 2021 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import _, api, fields, models
from odoo.exceptions import ValidationError


class FumocCategory(models.Model):
    _name = "fumoc.category"
    _description = "Catégorie"
    _parent_name = "parent_id"
    _parent_store = True
    _rec_name = "complete_name"
    _order = "complete_name"

    # ------------------------------------------------------
    # Fields declaration
    # ------------------------------------------------------
    name = fields.Char("Nom de la catégorie", index=True, required=True)
    complete_name = fields.Char(
        "Nom complet", compute="_compute_complete_name", store=True
    )

    parent_id = fields.Many2one(
        "fumoc.category", "Catégorie mère", index=True, ondelete="cascade"
    )
    parent_path = fields.Char(index=True)
    child_id = fields.One2many("fumoc.category", "parent_id", "Enfants cat")

    # ------------------------------------------------------
    # SQL Constraints
    # ------------------------------------------------------
    @api.constrains("parent_id")
    def _check_type_recursion(self):
        if not self._check_recursion():
            raise ValidationError(
                _("Vous ne pouvez pas créer de cateogries récursives.")
            )
        return True

    # ------------------------------------------------------
    # Default methods
    # ------------------------------------------------------
    @api.model
    def name_create(self, name):
        return self.create({"name": name}).name_get()[0]

    # ------------------------------------------------------
    # Computed fields / Search Fields
    # ------------------------------------------------------
    @api.depends("name", "parent_id.complete_name")
    def _compute_complete_name(self):
        for type in self:
            if type.parent_id:
                type.complete_name = "%s / %s" % (
                    type.parent_id.complete_name,
                    type.name,
                )
            else:
                type.complete_name = type.name

    # ------------------------------------------------------
    # Onchange / Constraints
    # ------------------------------------------------------

    # ------------------------------------------------------
    # CRUD methods (ORM overrides)
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Actions
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Business methods
    # ------------------------------------------------------
