# Copyright 2021 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import fields, models


class ResPartner(models.Model):
    _inherit = "res.partner"

    # ------------------------------------------------------
    # Fields declaration
    # ------------------------------------------------------
    is_customer = fields.Boolean("Est un client")
    is_supplier = fields.Boolean("Est un fournisseur")
    is_transporter = fields.Boolean("Est un transporteur")

    # Fields for customer
    regional_center_id = fields.Many2one(
        "res.partner.regional.center", string="Centrale régionale"
    )
    packaging_id = fields.Many2one("res.partner.packaging", string="Emballage")
    departure_day_ids = fields.Many2many(
        comodel_name="res.partner.day", string="Jour de départ"
    )
    billing_type_id = fields.Many2one(
        "res.partner.billing.type", string="Type de facturation"
    )
    delivery_note = fields.Text("Commentaire pour BL")
    billing_note = fields.Text("Commentaire pour Facture")
    call_frequency_id = fields.Many2one(
        "res.partner.call.frequency", string="Fréquence d'appel du client"
    )
    call_day = fields.Selection(
        [
            ("lundi", "Lundi"),
            ("mardi", "Mardi"),
            ("mercredi", "Mercredi"),
            ("jeudi", "Jeudi"),
            ("vendredi", "Vendredi"),
            ("samedi", "Samedi"),
        ],
        string="Jour d'appel du client",
    )
    customer_status_id = fields.Many2one(
        "res.partner.status", string="Statut du client"
    )
    # category_id = fields.Many2one(
    #     'res.partner.category', string='Catégorie')
    res_transporter_id = fields.Many2one(
        "res.partner.transporter", string="Nom du transporteur"
    )
    payment_method_id = fields.Many2one(
        "res.partner.payment.method", string="Méthode de paiement"
    )
    function_ids = fields.Many2many(
        comodel_name="res.partner.function", string="Postes"
    )
    user2_id = fields.Many2one("res.users", string="Commercial suivi")
    fumoc_category_id = fields.Many2one("fumoc.category", "Catégorie")

    invoicing_by_email = fields.Boolean("Facturation par e-mail ?")

    # ------------------------------------------------------
    # SQL Constraints
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Default methods
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Computed fields / Search Fields
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Onchange / Constraints
    # ------------------------------------------------------

    # ------------------------------------------------------
    # CRUD methods (ORM overrides)
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Actions
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Business methods
    # ------------------------------------------------------


class ResPartnerRegionalCenter(models.Model):
    _name = "res.partner.regional.center"
    _description = "Centrale régionale"

    name = fields.Char("Centrale régionale", required=True)


class ResPartnerPackaging(models.Model):
    _name = "res.partner.packaging"
    _description = "Emballage"

    name = fields.Char("Emballage", required=True)


class ResPartnerBillingType(models.Model):
    _name = "res.partner.billing.type"
    _description = "Type de facturation"

    name = fields.Char("Type de facturation", required=True)


class ResPartnerCallFrequency(models.Model):
    _name = "res.partner.call.frequency"
    _description = "Fréquence d'appel du client"

    name = fields.Char("Fréquence d'appel", required=True)


class ResPartnerStatus(models.Model):
    _name = "res.partner.status"
    _description = "Statut du client"

    name = fields.Char("Statut du client", required=True)


class ResPartnerPaymentMethod(models.Model):
    _name = "res.partner.payment.method"
    _description = "Mode de paiement"

    name = fields.Char("Mode de paiement", required=True)


class ResPartnerTransporter(models.Model):
    _name = "res.partner.transporter"
    _description = "Transporteur"

    name = fields.Char("Nom du transporteur", required=True)


class ResPartnerDay(models.Model):
    _name = "res.partner.day"
    _description = "Jours de la semaine"

    name = fields.Char("Jour", required=True)


class ResPartnerFunction(models.Model):
    _name = "res.partner.function"
    _description = "Poste occupé"

    name = fields.Char("Poste occupé", required=True)
